from distutils.core import setup
setup(
  name='stmpy',
  packages=['stmpy'],
  version='0.5.1',
  description='Support for simple state machines',
  author='Frank Alexander Kraemer',
  author_email='kraemer.frank@gmail.com',
  license='MIT',
  url='https://github.com/falkr/stmpy',
  download_url='https://github.com/falkr/stmpy/archive/0.2.tar.gz',
  keywords=['state machines', 'stm', 'automata'],
  classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Education',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5']
)
